import { Facet, Extension } from '@codemirror/state';
import { DOMEventMap, EditorView } from '@codemirror/view';

type EventHandler<event extends keyof DOMEventMap> = (e: DOMEventMap[event], v: EditorView) => void;
type Options = {
    /**
     * Determines how to render text. Defaults to `characters`.
     */
    displayText?: "blocks" | "characters";
    /**
     * Attach event handlers to the minimap container element.
     */
    eventHandlers?: {
        [event in keyof DOMEventMap]?: EventHandler<event>;
    };
    /**
     * The overlay shows the portion of the file currently in the viewport.
     * Defaults to `always`.
     */
    showOverlay?: "always" | "mouse-over";
};

/**
 * Enables a gutter to be drawn on the given line to the left
 * of the minimap, with the given color. Accepts all valid CSS
 * color values.
 */
declare const GutterDecoration: Facet<Record<number, string>, readonly Record<number, string>[]>;

declare function minimap(o?: Options): Extension;

export { GutterDecoration as MinimapGutterDecoration, minimap };
